@@ -27,14 +27,15 @@
 
 #define MAXDATASIZE 512
 
-int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
+int
+LLVMFuzzerTestOneInput (const uint8_t * data, size_t size)
 {
-	int ret_len;
+  int ret_len;
 
-	if (size > MAXDATASIZE) // same as max_len = <MAXDATASIZE> in .options file
-		return 0;
+  if (size > MAXDATASIZE)	// same as max_len = <MAXDATASIZE> in .options file
+    return 0;
 
-	asn1_get_length_ber(data, size, &ret_len);
+  asn1_get_length_ber (data, size, &ret_len);
 
-	return 0;
+  return 0;
 }
