@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2021 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -68,7 +68,7 @@ _asn1_add_single_node (unsigned int type)
 /* Return: NULL if not found.                                     */
 /******************************************************************/
 asn1_node
-_asn1_find_left (asn1_node node)
+_asn1_find_left (asn1_node_const node)
 {
   if ((node == NULL) || (node->left == NULL) || (node->left->down == node))
     return NULL;
@@ -78,11 +78,11 @@ _asn1_find_left (asn1_node node)
 
 
 int
-_asn1_create_static_structure (asn1_node pointer, char *output_file_name,
-			       char *vector_name)
+_asn1_create_static_structure (asn1_node_const pointer,
+			       char *output_file_name, char *vector_name)
 {
   FILE *file;
-  asn1_node p;
+  asn1_node_const p;
   unsigned long t;
 
   file = fopen (output_file_name, "w");
@@ -182,19 +182,21 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
   int move;
   int result;
   unsigned int type;
+  list_type *e_list = NULL;
 
+  if (errorDescription)
+    errorDescription[0] = 0;
 
   if (*definitions != NULL)
     return ASN1_ELEMENT_NOT_EMPTY;
 
   move = UP;
 
-  k = 0;
-  while (array[k].value || array[k].type || array[k].name)
+  for (k = 0; array[k].value || array[k].type || array[k].name; k++)
     {
       type = convert_old_type (array[k].type);
 
-      p = _asn1_add_static_node (type & (~CONST_DOWN));
+      p = _asn1_add_static_node (&e_list, type & (~CONST_DOWN));
       if (array[k].name)
 	_asn1_set_name (p, array[k].name);
       if (array[k].value)
@@ -204,9 +206,17 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
 	*definitions = p;
 
       if (move == DOWN)
-	_asn1_set_down (p_last, p);
+	{
+	  if (p_last && p_last->down)
+	    _asn1_delete_structure (e_list, &p_last->down, 0);
+	  _asn1_set_down (p_last, p);
+	}
       else if (move == RIGHT)
-	_asn1_set_right (p_last, p);
+	{
+	  if (p_last && p_last->right)
+	    _asn1_delete_structure (e_list, &p_last->right, 0);
+	  _asn1_set_right (p_last, p);
+	}
 
       p_last = p;
 
@@ -216,11 +226,8 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
 	move = RIGHT;
       else
 	{
-	  while (1)
+	  while (p_last != *definitions)
 	    {
-	      if (p_last == *definitions)
-		break;
-
 	      p_last = _asn1_find_up (p_last);
 
 	      if (p_last == NULL)
@@ -234,7 +241,6 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
 		}
 	    }			/* while */
 	}
-      k++;
     }				/* while */
 
   if (p_last == *definitions)
@@ -243,7 +249,7 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
       if (result == ASN1_SUCCESS)
 	{
 	  _asn1_change_integer_value (*definitions);
-	  _asn1_expand_object_id (*definitions);
+	  result = _asn1_expand_object_id (&e_list, *definitions);
 	}
     }
   else
@@ -265,11 +271,11 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
 
   if (result != ASN1_SUCCESS)
     {
-      _asn1_delete_list_and_nodes ();
+      _asn1_delete_list_and_nodes (e_list);
       *definitions = NULL;
     }
   else
-    _asn1_delete_list ();
+    _asn1_delete_list (e_list);
 
   return result;
 }
@@ -287,13 +293,13 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
 int
 asn1_delete_structure (asn1_node * structure)
 {
-  return asn1_delete_structure2(structure, 0);
+  return _asn1_delete_structure (NULL, structure, 0);
 }
 
 /**
  * asn1_delete_structure2:
  * @structure: pointer to the structure that you want to delete.
- * @flags: additional flags (see %ASN1_DELETE_FLAG)
+ * @flags: additional flags (see %ASN1_DELETE_FLAG_ZEROIZE)
  *
  * Deletes the structure *@structure.  At the end, *@structure is set
  * to NULL.
@@ -303,6 +309,13 @@ asn1_delete_structure (asn1_node * structure)
  **/
 int
 asn1_delete_structure2 (asn1_node * structure, unsigned int flags)
+{
+  return _asn1_delete_structure (NULL, structure, flags);
+}
+
+int
+_asn1_delete_structure (list_type * e_list, asn1_node * structure,
+			unsigned int flags)
 {
   asn1_node p, p2, p3;
 
@@ -323,6 +336,8 @@ asn1_delete_structure2 (asn1_node * structure, unsigned int flags)
 	    {
 	      p3 = _asn1_find_up (p);
 	      _asn1_set_down (p3, p2);
+	      if (e_list)
+		_asn1_delete_node_from_list (e_list, p);
 	      _asn1_remove_node (p, flags);
 	      p = p3;
 	    }
@@ -342,6 +357,8 @@ asn1_delete_structure2 (asn1_node * structure, unsigned int flags)
 		}
 	      else
 		_asn1_set_right (p3, p2);
+	      if (e_list)
+		_asn1_delete_node_from_list (e_list, p);
 	      _asn1_remove_node (p, flags);
 	      p = NULL;
 	    }
@@ -353,7 +370,6 @@ asn1_delete_structure2 (asn1_node * structure, unsigned int flags)
 }
 
 
-
 /**
  * asn1_delete_element:
  * @structure: pointer to the structure that contains the element you
@@ -391,16 +407,20 @@ asn1_delete_element (asn1_node structure, const char *element_name)
   return asn1_delete_structure (&source_node);
 }
 
+#ifndef __clang_analyzer__
 asn1_node
-_asn1_copy_structure3 (asn1_node source_node)
+_asn1_copy_structure3 (asn1_node_const source_node)
 {
-  asn1_node dest_node, p_s, p_d, p_d_prev;
+  asn1_node_const p_s;
+  asn1_node dest_node, p_d, p_d_prev;
   int move;
 
   if (source_node == NULL)
     return NULL;
 
   dest_node = _asn1_add_single_node (source_node->type);
+  if (dest_node == NULL)
+    return dest_node;
 
   p_s = source_node;
   p_d = dest_node;
@@ -423,6 +443,8 @@ _asn1_copy_structure3 (asn1_node source_node)
 	      _asn1_set_down (p_d_prev, p_d);
 	      continue;
 	    }
+	  p_d->start = p_s->start;
+	  p_d->end = p_s->end;
 	}
 
       if (p_s == source_node)
@@ -444,13 +466,21 @@ _asn1_copy_structure3 (asn1_node source_node)
 	}
     }
   while (p_s != source_node);
-
   return dest_node;
 }
+#else
+
+/* Non-production code */
+asn1_node
+_asn1_copy_structure3 (asn1_node_const source_node)
+{
+  return NULL;
+}
+#endif /* __clang_analyzer__ */
 
 
 static asn1_node
-_asn1_copy_structure2 (asn1_node root, const char *source_name)
+_asn1_copy_structure2 (asn1_node_const root, const char *source_name)
 {
   asn1_node source_node;
 
@@ -548,7 +578,7 @@ _asn1_type_choice_config (asn1_node node)
 
 
 static int
-_asn1_expand_identifier (asn1_node * node, asn1_node root)
+_asn1_expand_identifier (asn1_node * node, asn1_node_const root)
 {
   asn1_node p, p2, p3;
   char name2[ASN1_MAX_NAME_SIZE + 2];
@@ -670,7 +700,7 @@ _asn1_expand_identifier (asn1_node * node, asn1_node root)
  *   @source_name is not known.
  **/
 int
-asn1_create_element (asn1_node definitions, const char *source_name,
+asn1_create_element (asn1_node_const definitions, const char *source_name,
 		     asn1_node * element)
 {
   asn1_node dest_node;
@@ -705,10 +735,10 @@ asn1_create_element (asn1_node definitions, const char *source_name,
  * from the @name element inside the structure @structure.
  **/
 void
-asn1_print_structure (FILE * out, asn1_node structure, const char *name,
+asn1_print_structure (FILE * out, asn1_node_const structure, const char *name,
 		      int mode)
 {
-  asn1_node p, root;
+  asn1_node_const p, root;
   int k, indent = 0, len, len2, len3;
 
   if (out == NULL)
@@ -830,7 +860,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:0x");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (p->value)[k + len2]);
+		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_ENUMERATED:
@@ -841,7 +871,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:0x");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (p->value)[k + len2]);
+		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_BOOLEAN:
@@ -863,7 +893,8 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		      fprintf (out, "  value(%i):",
 			       (len - 1) * 8 - (p->value[len2]));
 		      for (k = 1; k < len; k++)
-			fprintf (out, "%02x", (p->value)[k + len2]);
+			fprintf (out, "%02x",
+				 (unsigned) (p->value)[k + len2]);
 		    }
 		}
 	      break;
@@ -903,7 +934,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (p->value)[k + len2]);
+		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_OBJECT_ID:
@@ -918,7 +949,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:");
 		  if (len2 > 0)
 		    for (k = 0; k < len2; k++)
-		      fprintf (out, "%02x", (p->value)[k + len3]);
+		      fprintf (out, "%02x", (unsigned) (p->value)[k + len3]);
 		}
 	      break;
 	    case ASN1_ETYPE_SET:
@@ -1047,9 +1078,9 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
  *   @name is not known, %ASN1_GENERIC_ERROR if pointer @num is %NULL.
  **/
 int
-asn1_number_of_elements (asn1_node element, const char *name, int *num)
+asn1_number_of_elements (asn1_node_const element, const char *name, int *num)
 {
-  asn1_node node, p;
+  asn1_node_const node, p;
 
   if (num == NULL)
     return ASN1_GENERIC_ERROR;
@@ -1085,20 +1116,20 @@ asn1_number_of_elements (asn1_node element, const char *name, int *num)
  *   the OID.
  **/
 const char *
-asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
+asn1_find_structure_from_oid (asn1_node_const definitions,
+			      const char *oidValue)
 {
-  char definitionsName[ASN1_MAX_NAME_SIZE], name[2 * ASN1_MAX_NAME_SIZE + 1];
+  char name[2 * ASN1_MAX_NAME_SIZE + 2];
   char value[ASN1_MAX_NAME_SIZE];
   asn1_node p;
   int len;
   int result;
+  const char *definitionsName;
 
   if ((definitions == NULL) || (oidValue == NULL))
     return NULL;		/* ASN1_ELEMENT_NOT_FOUND; */
 
-
-  strcpy (definitionsName, definitions->name);
-  strcat (definitionsName, ".");
+  definitionsName = definitions->name;
 
   /* search the OBJECT_ID into definitions */
   p = definitions->down;
@@ -1107,8 +1138,7 @@ asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
       if ((type_field (p->type) == ASN1_ETYPE_OBJECT_ID) &&
 	  (p->type & CONST_ASSIGN))
 	{
-	  strcpy (name, definitionsName);
-	  strcat (name, p->name);
+	  snprintf (name, sizeof (name), "%s.%s", definitionsName, p->name);
 
 	  len = ASN1_MAX_NAME_SIZE;
 	  result = asn1_read_value (definitions, name, value, &len);
@@ -1130,22 +1160,20 @@ asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
 
 /**
  * asn1_copy_node:
- * @dst: Destination asn1_node node.
+ * @dst: Destination asn1 node.
  * @dst_name: Field name in destination node.
- * @src: Source asn1_node node.
+ * @src: Source asn1 node.
  * @src_name: Field name in source node.
  *
- * Create a deep copy of a asn1_node variable.
+ * Create a deep copy of a asn1_node variable. That
+ * function requires @dst to be expanded using asn1_create_element().
  *
  * Returns: Return %ASN1_SUCCESS on success.
  **/
 int
 asn1_copy_node (asn1_node dst, const char *dst_name,
-		asn1_node src, const char *src_name)
+		asn1_node_const src, const char *src_name)
 {
-/* FIXME: rewrite using copy_structure().
- * It seems quite hard to do.
- */
   int result;
   asn1_node dst_node;
   void *data = NULL;
@@ -1179,3 +1207,19 @@ asn1_copy_node (asn1_node dst, const char *dst_name,
 
   return result;
 }
+
+/**
+ * asn1_dup_node:
+ * @src: Source asn1 node.
+ * @src_name: Field name in source node.
+ *
+ * Create a deep copy of a asn1_node variable. This function
+ * will return an exact copy of the provided structure.
+ *
+ * Returns: Return %NULL on failure.
+ **/
+asn1_node
+asn1_dup_node (asn1_node_const src, const char *src_name)
+{
+  return _asn1_copy_structure2 (src, src_name);
+}
