@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2026 Free Software Foundation, Inc.
+ * Copyright (C) 2000-2021 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -14,11 +14,14 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see
- * <https://www.gnu.org/licenses/>.
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 
 #include <string.h>		/* for strverscmp */
 
