@@ -1,5 +1,5 @@
 /* asn1Parser.c -- program to parse a file with ASN1 definitions
- * Copyright (C) 2002-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2021 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -25,17 +25,18 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <getopt.h>
+#include <assert.h>
 
 #include <libtasn1.h>
 
-#include <progname.h>
-#include <version-etc.h>
+#include "progname.h"
+#include "version-etc.h"
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
-#define ATTR_NO_RETRUN
+# define ATTR_NO_RETRUN
 #else
-#define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
+# define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
 #endif
 
 ATTR_NO_RETRUN static void
@@ -121,12 +122,22 @@ main (int argc, char *argv[])
 	  checkSyntaxOnly = 1;
 	  break;
 	case 'o':		/* OUTPUT */
-	  outputFileName = (char *) malloc (strlen (optarg) + 1);
-	  strcpy (outputFileName, optarg);
+	  assert (optarg != NULL);
+	  outputFileName = strdup (optarg);
+	  if (outputFileName == NULL)
+	    {
+	      fprintf (stderr, "Memory error\n");
+	      exit (1);
+	    }
 	  break;
 	case 'n':		/* VECTOR NAME */
-	  vectorName = (char *) malloc (strlen (optarg) + 1);
-	  strcpy (vectorName, optarg);
+	  assert (optarg != NULL);
+	  vectorName = strdup (optarg);
+	  if (vectorName == NULL)
+	    {
+	      fprintf (stderr, "Memory error\n");
+	      exit (1);
+	    }
 	  break;
 	case '?':		/* UNKNOW OPTION */
 	  fprintf (stderr,
@@ -139,7 +150,7 @@ main (int argc, char *argv[])
 	default:
 	  fprintf (stderr,
 		   "asn1Parser: ?? getopt returned character code Ox%x ??\n",
-		   (unsigned)option_result);
+		   (unsigned) option_result);
 	}
 
     }
@@ -153,6 +164,11 @@ main (int argc, char *argv[])
   else
     {
       inputFileName = (char *) malloc (strlen (argv[optind]) + 1);
+      if (inputFileName == NULL)
+	{
+	  fprintf (stderr, "Memory error\n");
+	  exit (1);
+	}
       strcpy (inputFileName, argv[optind]);
     }
 
