@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2018 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2021 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -38,9 +38,11 @@ main (int argc, char *argv[])
   if (argc > 1)
     verbose = 1;
 
-  printf("Test 1\n");
+  printf ("Test 1\n");
 
-  result = asn1_array2tree (CVE_2018_1000654_1_asn1_tab, &definitions, errorDescription);
+  result =
+    asn1_array2tree (CVE_2018_1000654_1_asn1_tab, &definitions,
+		     errorDescription);
   if (result != ASN1_RECURSION)
     {
       asn1_perror (result);
@@ -50,9 +52,11 @@ main (int argc, char *argv[])
 
   asn1_delete_structure (&definitions);
 
-  printf("Test 2\n");
+  printf ("Test 2\n");
 
-  result = asn1_array2tree (CVE_2018_1000654_2_asn1_tab, &definitions, errorDescription);
+  result =
+    asn1_array2tree (CVE_2018_1000654_2_asn1_tab, &definitions,
+		     errorDescription);
   if (result != ASN1_RECURSION)
     {
       asn1_perror (result);
